@@ -17,7 +17,7 @@ class Action(Enum):
     SelectPopup="SelectPopup"
     SelectPopup2="SelectPopup2"
     GotoPage="GotoPage"
-    Login="Login"
+    WebPage="WebPage"
     Security="Security"
     Upload="Upload"
     Pdf="Pdf"
